@@ -2,7 +2,8 @@ import pygpiotools
 import time
 import serial
 
-print(f"Drivers loaded: {pygpiotools.list()}")
+print(pygpiotools.__version__)
+#print(f"Drivers loaded: {pygpiotools.list()}")
 #handle = pygpiotools.open("pl2303", "/dev/ttyUSB0")
 #handle = pygpiotools.open("pl2303", "com5")
 #ser = serial.Serial('com5:', 1000000)
